pub struct Rectangle {
pub x: f64,
pub y: f64,
pub width: f64,
pub height: f64,
pub color: Color,
}Expand description
A rectangle to draw on a Canvas
Sizes used here are not in terminal cell. This is much more similar to the mathematic coordinate system.
Fields
x: f64The x position of the rectangle.
The rectangle is positioned from its bottom left corner.
y: f64The y position of the rectangle.
The rectangle is positioned from its bottom left corner.
width: f64The width of the rectangle.
height: f64The height of the rectangle.
color: ColorThe color of the rectangle.
Implementations