pub enum GraphType {
Scatter,
Line,
Bar,
}Expand description
Used to determine which style of graphing to use
Variants
Scatter
Draw each point. This is the default.
Line
Draw a line between each following point.
The order of the lines will be the same as the order of the points in the dataset, which allows this widget to draw lines both left-to-right and right-to-left
Bar
Draw a bar chart. This will draw a bar for each point in the dataset.