pub enum TitlePosition {
Top,
Bottom,
}Expand description
Defines the position of the title.
The title can be positioned on top or at the bottom of the block.
Example
use ratatui::widgets::{Block, TitlePosition};
Block::bordered()
.title_position(TitlePosition::Top)
.title("Top Title");
Block::bordered()
.title_position(TitlePosition::Bottom)
.title("Bottom Title");Variants
Top
Position the title at the top of the block.
Bottom
Position the title at the bottom of the block.